#!/usr/local/bin/python3

# Change the dome shutter azimuth by an angle 
#
# Copyright 2018 John Kielkopf
#
#
# Assumes DLI controller these connections --
#
#   1  Rotate On/Off
#   2  Azimuth Incr/Decr
#   3  
#   4
#   5  Upper On/Off
#   6  Upper Open/Closed
#   7  Lower On/Off
#   8  Lower Open/Closed


# CDK20N Sirius dome scans about 6 (24 degrees) tags in 10 seconds

import sys
import time
import math
import dlipower

if len(sys.argv) == 1:
  sys.exit("Usage: change_azimuth.py angle (Signed angle as an argument)")
  exit()
elif len(sys.argv) == 2:
  delta_azimuth = float(sys.argv[1])
else:
  sys.exit("Usage: change_azimuth.py angle (Provide signed angle as an argument)")
  exit() 
 
if (delta_azimuth > 90.) or (delta_azimuth < -90.):
  print("Request exceeded 90 degree limit")  
  print("Use a smaller increment")
  exit()


# Switch settings for the DLI dome control switch 

SWITCHIP="192.168.1.249"
USER=""
PASSWORD=""

# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.
switch=dlipower.PowerSwitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify the switch
if not switch.verify():
  print("Cannot talk to the switch")
  sys.exit(1)
  
if (delta_azimuth > 0.):

# Power increase azimuth on
  switch.on(2)
  time.sleep(0.25)
  switch.on(1)

# Print a message
  print("Increasing dome azimuth")

# Wait the dome to rotate the requested angle
  dps = 2.5
  delay = delta_azimuth/dps
  time.sleep(delay)

# Power increase dome azimuth off
  switch.off(1)
  switch.off(2)

# Print the switch state again
  print("Dome stopped")

elif (delta_azimuth < 0.):

# Power decrease azimuth on
  switch.off(2)
  time.sleep(0.25)
  switch.on(1)

# Print the switch state
  print("Decreasing dome azimuth")

# Wait the dome to rotate the requested angle
  dps = 2.5
  delay = -1.*delta_azimuth/dps
  time.sleep(delay)

# Power decrease dome azimuth off
  switch.off(1)
  switch.off(2)

# Print the switch state again
  print("Dome stopped")

else:
  print("No rotation requested")  
  
exit()
  
