#!/usr/bin/python

# Change the dome shutter azimuth by an angle 
#
# Copyright 2012-2015 John Kielkopf
#
#
# Assumes DLI controller these connections --
#
#   1  Azimuth Incr
#   2  Azimuth Decr
#   3  
#   4
#   5  
#   6  
#   7  
#   8  
# 
# Based on software from Dwight Hubbard d@dhub.me
#   provided as an example on the DLI website           
#                                                                          
#                                                                          
# Date:  December 6, 2015                                                  
# Version: 1.6
# For CDK700                                                        
#                                                                          
# This file is part of PyDome                                              

import sys
import time
import math
import argparse
import os    

# CDK700 dome parameters
dps = 1.5

# Azimuth tolerance for setting
tolazimuth = 1.


parser= argparse.ArgumentParser(description = ' Rotate the dome by an angle in degrees')
parser.add_argument('-a', type = float)

if len(sys.argv) == 1:
  sys.exit("Usage:  dome_azimuth_change.py angle (Signed angle as an argument)")
  exit()
elif len(sys.argv) == 2:
  delazimuth = float(sys.argv[1])      ##### RH change 24 Nov 2015
elif len(sys.argv) == 3:
  args = parser.parse_args()
  delazimuth = args.a
else:
  sys.exit("Usage: dome_azimuth_change.py angle (Signed angle as an argument)")
  exit() 
 
if (delazimuth > 90.) or (delazimuth < -90.):
  print('Request exceeds 90 degree limit.  Use a smaller increment.')
  exit()


# The dli module needs to be in the python path.  
# Add current directory to the path so we can find the dli module

sys.path.append('.')

# Import the DLI module -- must be in the same directory as this py file

import dli


# Switch settings for the DLI device

# CDK700
SWITCHIP="192.168.10.252"
USER=""
PASSWORD=""

# Test that the dome_monitor.py program is running

processname = 'dome_monitor.py'
processlist = os.popen("ps -Af").read()
proccount = processlist.count(processname)

if proccount > 1:
  print "%s is running %d processes\n" % (processname, proccount)
  exit()

if proccount == 0:
  print "%s is not running\n" % processname
  exit()

# Note starting time in Unix seconds and in UTC

timestamp = int(time.time())
startutc = time.strftime("%Y%m%d %H:%M:%S", time.gmtime())

# Test for lockfile

lockfile = "/usr/local/observatory/status/domerotation"

if os.path.exists(lockfile):

  # Another process is running the dome
  lockfp = open(lockfile,'r')
  oldtime = int(float(lockfp.readline()))
  runtime = timestamp - oldtime
  print "Dome control in use: %d\n" % runtime
  exit()

else:

  # We take control and leave a message

  lockfp = open(lockfile,'w')
  lockfp.write('%d\n' % timestamp)
  lockfp.write('%s\n' % startutc)
  lockfp.close()

# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.

switch=dli.powerswitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify the switch
if not switch.verify():
  print "Cannot talk to the switch"
  sys.exit(1)

# Print diagnostic
#switch.printstatus()
  
# Map an angle in degrees to  0 <= angle < 360 

def map360(angle):

  if (angle < 0.0):   
    n = int(angle / 360.0) - 1
    return (angle - float(n) * 360.0)
   
  elif (angle >= 360.0):  
    n = int(angle / 360.0)
    return (angle - float(n) * 360.0)
   
  else:   
    return (angle)
  

# Map an angle in degrees to  -180 <= angle < 180 

def map180(angle):

  angle360 = map360(angle)
   
  if (angle360 >= 180.0):  
    return (angle360 - 360.0)
   
  else:   
    return (angle360)


# Set azimuth change for newazimuth on the command line
# Disabled in this version
# delazimuth = map180(newazimuth - nowazimuth)


# This routine uses on/off and direction state relays

if abs(delazimuth) > tolazimuth:
    
  if (delazimuth > 0.):
    
    # Power increase azimuth on
    switch.off(1)
    time.sleep(0.25)
    switch.on(2)
    starttime = time.time()

    # Print diagnostic
    # print 'Increasing dome azimuth'

    # Wait the dome to rotate the requested angle
    delay = delazimuth/dps
    time.sleep(delay)

    # Power increase dome azimuth off
    switch.off(1)
    switch.off(2)
    stoptime = time.time()

    # Print diagnostic
    # print 'Dome stopped'
    
    # Correct the azimuth based on the run time after the last tag    
    lastazimuthstatus = open('/usr/local/observatory/status/domeazimuth','r')
    lastazimuthstr = lastazimuthstatus.read(40)				        
    lastazimuthstatus.close()
    lastazimuth = float(lastazimuthstr)
    tagazimuthstatus = open('/usr/local/observatory/status/dometag','r')
    tagazimuthstr = tagazimuthstatus.read(40)				        
    tagazimuthstatus.close()
    tagtime = float(tagazimuthstr.split()[0])
    tagdelay = 0.
    if (starttime < tagtime):
      tagdelay = stoptime - tagtime         
    else:
      tagdelay = stoptime - starttime
    nowazimuth = map360(lastazimuth + tagdelay*dps)  
    
    # Update the azimuth at this instant    
    nowazimuthstatus = open('/usr/local/observatory/status/domeazimuth','w')    
    nowazimuthstatus.write("%f \n" % nowazimuth)
    nowazimuthstatus.close()


  elif (delazimuth < 0.):

    # Power decrease azimuth on
    switch.off(2)
    time.sleep(0.25)
    switch.on(1)
    starttime = time.time()

    # Print diagnostic
    # print 'Decreasing dome azimuth'

    # Wait for the dome to rotate the requested angle
    delay = -1.*delazimuth/dps
    time.sleep(delay)

    # Power decrease dome azimuth off
    switch.off(1)
    switch.off(2)
    
    # Print diagnostic
    # print 'Dome stopped'
    
    # Correct the azimuth based on the run time after the last tag
    stoptime = time.time()
    lastazimuthstatus = open('/usr/local/observatory/status/domeazimuth','r')
    lastazimuthstr = nowazimuthstatus.read(40)				        
    lastazimuthstatus.close()
    lastazimuth = float(lastazimuthstr)
    tagazimuthstatus = open('/usr/local/observatory/status/dometag','r')
    tagazimuthstr = nowazimuthstatus.read(60)				        
    tagazimuthstatus.close()
    tagtime = float(tagazimuthstr.split()[0])
    tagdelay = 0.
    if (starttime < tagtime):
      tagdelay = stoptime - tagtime         
    else:
      tagdelay = stoptime - starttime
    nowazimuth = map360(lastazimuth - tagdelay*dps)  
    
    # Update the azimuth at this instant    
    nowazimuthstatus = open('/usr/local/observatory/status/domeazimuth','w')    
    nowazimuthstatus.write("%f \n" % nowazimuth)
    nowazimuthstatus.close()
  
  else:
    pass

else:
  pass
  
# Print diagnostic
print ("Current azimuth: %.2f" % (nowazimuth))

# Remove the lockfile

if os.path.exists(lockfile):

  # Remove the lock to allow future access
  os.remove(lockfile)

exit()
