#!/usr/bin/python

# Change the dome shutter azimuth by an angle 
#
# Copyright 2012 John Kielkopf
#
#
# Assumes DLI controller these connections --
#
#   1  
#   2  
#   3  
#   4
#   5  
#   6  
#   7  On to rotate
#   8  On to increase azimuth
# 
# Based on software from Dwight Hubbard d@dhub.me
#   provided as an example on the DLI website           

# CDK20N Sirius dome scans about 6 (24 degrees) tags in 10 seconds

import sys
import time
import math
import argparse

parser= argparse.ArgumentParser(description = ' Rotate the dome by an angle in degrees')
parser.add_argument('-a', type = float)

if len(sys.argv) == 1:
  sys.exit("Usage: change_azimuth.py angle (Signed angle as an argument)")
  exit()
elif len(sys.argv) == 2:
  delta_azimuth = float(sys.argv[1])
elif len(sys.argv) == 3:
  args = parser.parse_args()
  delta_azimuth = args.a
else:
  sys.exit("Usage: change_azimuth.py angle (Provide signed angle as an argument)")
  exit() 
 
if (delta_azimuth > 90.) or (delta_azimuth < -90.):
  print('Request exceeds 90 degree limit.  Use a smaller increment.')
  exit()


# The dli module needs to be in the python path.  
# Add current directory to the path so we can find the dli module

sys.path.append('.')

# Import the DLI module -- must be in the same directory as this py file

import dli


# Switch settings for the DLI device

SWITCHIP="192.168.1.250"
USER=""
PASSWORD=""

# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.
switch=dli.powerswitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify the switch
if not switch.verify():
  print "Cannot talk to the switch"
  sys.exit(1)

# Print the current state of all the outlets
#switch.printstatus()
  
if (delta_azimuth > 0.):

# Power increase azimuth on
  switch.on(8)

  time.sleep(0.25)

# Power the rotation switch on
  switch.on(7)

# Wait the dome to rotate the requested angle
  dps = 3.6
  delay = delta_azimuth/dps
  time.sleep(delay)

# Power rotation switch off
  switch.off(7)
  
  time.sleep(0.25)
  
# Power increase azimuth off
  switch.off(8)
  
# Print the rotation state 
#  print 'Rotation state  ',switch.status(7)

elif (delta_azimuth < 0.):

# Power increase azimuth off
  switch.off(8)

  time.sleep(0.25)

# Power the rotation switch on
  switch.on(7)


# Wait the dome to rotate the requested angle
  dps = 3.6
  delay = -1.*delta_azimuth/dps
  time.sleep(delay)

# Power the rotation switch off
  switch.off(7)
  
  time.sleep(0.25)

# Print the switch state again
#  print 'Rotation state  ',switch.status(7)

else:
  print 'No rotation requested.'  
  
exit()
  
